@@ -2,6 +2,7 @@
 
 import click
 
+from .cmj.cli import cmj_analyze
 from .dropjump.cli import dropjump_analyze
 
 
@@ -14,6 +15,7 @@ def cli() -> None:
 
 # Register commands from submodules
 cli.add_command(dropjump_analyze)
+cli.add_command(cmj_analyze)
 
 
 if __name__ == "__main__":
